
#ifndef __CFMFLASH_LO_H_
#define __CFMFLASH_LO_H_

#include <BDMlib.h>
#include <stdio.h>
#include <stdlib.h>
#include <getopt.h>
#include <netinet/in.h>

#define MCF_IPSBAR 0x40000000

#include "m5282sim.h"

int flash_init(const char *bdm_device);
int flash_shutdown(void);
int flash_info(void);
int flash_erase(void);
int flash_erase_region(unsigned long region, unsigned long length, int verbose);
int flash_write(unsigned long region, size_t length, unsigned char *buf);
int flash_read(unsigned long region, size_t length, unsigned char *buf);
int flash_verify_region(unsigned long region, unsigned long length, int verbose);
int flash_verify(void);

/*
 * Flash memory blocksize and blockcount.
 */
#define FLASH_BLOCKSIZE         (1024*2)
#define FLASH_NUMBLOCKS         256
#define FLASH_SIZE              FLASH_BLOCKSIZE * FLASH_NUMBLOCKS

/*
 * General settings, FLASH_OFFSET based on FLASHBAR chip select
 */
#define BUSWIDTH                4
#define CFM_OFFSET              0xF0000000
#define CFM_BACKDOOR_OFFSET     (MCF_IPSBAR+0x04000000)

/*
 * CFM User Mode Commands
 */
#define CFMCMD_RDARY1   0x05    /* erase verify */
#define CFMCMD_PGM      0x20    /* longword program */
#define CFMCMD_PGERS    0x40    /* page erase */
#define CFMCMD_MASERS   0x41    /* mass erase */
#define CFMCMD_PGERSVER 0x06    /* page erase verify */

/*
 * CFM Status Bits
 **/
#define CFMUSTAT_CBEIF  0x80
#define CFMUSTAT_CCIF   0x40
#define CFMUSTAT_PVIOL  0x20
#define CFMUSTAT_ACCERR 0x10
#define CFMUSTAT_BLANK  0x04

#endif /* __MCMFLASH_LO_H_ */
